% [cl_stepresp, cl_freqresp] = compute_cl_response(T1, T2, T3, Q_basis, b, t, w)
% computes step response and frequency reponse of the Youla parametrized
% plant
% T1 + T2*Q*T3 where Q = sum_k (Q_k * b(k)),
% where b is a vector of cvx-variables.
%
% I.e. the resulting step response cl_stepresp
% and frequency response cl_freqresp are (three dimensional) matrices of
% cvx-expressions in the variable b
%
% Note that the output dimensions of step and freqresp are not consistent.
function [cl_stepresp, cl_freqresp] = qcvx_compute_cl_response(T1, T2, T3, Q_basis, b, t, w)

% Compute step response
cl_stepresp = step(T1,t);
for k=1:numel(Q_basis)
    cl_stepresp = cl_stepresp + step(T2*Q_basis{k}*T3, t) * b(k);
end

% Compute frequency response
cl_freqresp = freqresp(T1,w);
for k=1:numel(Q_basis)
    cl_freqresp = cl_freqresp + freqresp(T2*Q_basis{k}*T3, w) * b(k);
end
